@@ -38,6 +38,13 @@
 #define OPENSSL_VERSION_NUMBER 0x1000107fL
 #endif
 
+/* OpenSSL 3.0 ****************************************************************/
+
+#ifndef OPENSSL_VERSION_PREREQ
+#define OPENSSL_VERSION_PREREQ(maj,min) 0
+#endif
+
+
 /* OpenSSL ********************************************************************/
 void HsOpenSSL_init();
 void HsOpenSSL_OPENSSL_free(void* ptr);
@@ -105,4 +112,6 @@ long HsOpenSSL_SSL_set_options(SSL* ssl, long options);
 long HsOpenSSL_SSL_clear_options(SSL* ssl, long options);
 long HsOpenSSL_SSL_set_tlsext_host_name(SSL* ssl, char* host_name);
 
+int HsOpenSSL_enable_hostname_validation(SSL* ssl, char* host_name, size_t host_len);
+
 #endif
